<!doctype html>
<html class="no-js" lang="nl">

{% set app_package = app_package|default('pyoes', true) -%}
{% set active_title = active_title -%}

{% set service_nav = service_nav -%}
{% set main_nav = main_nav -%}
{% set dropdown_main_nav = dropdown_main_nav -%}
{% set active_main_nav = active_main_nav -%}
{% set login_nav = login_nav -%}
{% set login_sub_nav = login_sub_nav -%}
{% set service_nav = service_nav -%}
{% set home_link = home_link -%}
{% set footer_nav = footer_nav -%}
{% set mailto_error = mailto_error -%}

{% set default_footer_nav = [
	('Toegankelijkheid', 'https://www.onroerenderfgoed.be/toegankelijkheid'),
	('Juridische Informatie', 'https://www.onroerenderfgoed.be/nl/juridisch'),
	('Privacybeleid', 'https://www.onroerenderfgoed.be/nl/over-ons/privacybeleid/')
]
-%}

{% set footer_nav = footer_nav|default(default_footer_nav) -%}

{% set datum_copyright = datum_copyright|default('2017') -%}

<head>
  {% block html_header scoped %}
    <meta charset="utf-8">

    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <title>{% block html_title %}Onroerend Erfgoed{% endblock %}</title>

    <link rel="stylesheet"
          href="{% block app_css %}{{ request.static_path(app_package + ':static/css/app.css') }}{% endblock %}"/>

    <script src="{{ request.static_path(app_package + ':static/bower_components/modernizr/modernizr.js') }}"></script>

    {% block css -%}
      {% set default_css_files = []-%}

      {% set css_files = css_files|default(default_css_files) -%}
      {% for css in css_files -%}
        <link rel="stylesheet" href="{{ css }}"/>
      {% endfor %}
    {% endblock -%}

    {% block javascript scoped -%}
      {% set default_js_files = [
			request.static_path(app_package + ':static/bower_components/jquery/dist/jquery.min.js'),
		] -%}
      {% set js_files = js_files|default(default_js_files) -%}
      {% for js in js_files -%}
        <script type="text/javascript" src="{{ js }}"></script>
      {% endfor -%}
    {% endblock -%}

    {% block ga %}
      {% set ga_key = ga_key|default(request.registry.settings["ga.tracker_key"]) %}
      {% from 'macros.jinja2' import ga_tracker %}
      {% if ga_key %}
        {{ ga_tracker(ga_key) }}
      {% endif %}
    {% endblock %}
  {% endblock %}

</head>
<body>
<div class="container">
  {% block vlaanderen_header scoped %}
    <script type="text/javascript" src="//widgets.vlaanderen.be/widget/live/5499d8dc0848446e91022c6dba9db343?mtime=1421237274"></script>
  {% endblock %}

  {% block header scoped %}
    {% include "pyoes/header.jinja2" %}
  {% endblock %}

  {% block messages scoped %}
  {% endblock %}

  {% block content scoped %}
  {% endblock %}
  <div class="push"></div>
</div>
<div id="footerContainer">
  {% block footer scoped %}
    {% include "pyoes/footer.jinja2" %}
  {% endblock %}

  {% block vlaanderen_footer scoped %}
    <script type="text/javascript" src="//widgets.vlaanderen.be/widget/live/79a9f632dc8e45aa884f7924ee16f7bf?mtime=1421237274"></script>
  {% endblock %}
</div>
<script src="{{ request.static_path(app_package + ':static/bower_components/foundation/js/foundation.min.js') }}"></script>
<script src="{{ request.static_path(app_package + ':static/js/app.js') }}"></script>

</body>
</html>
