{% extends "layout.jinja2" %}

{% block header scoped %}
    {% include "pyoes/header.jinja2" %}
{% endblock %}

{% block content scoped %}
<!-- content -->
<div class="row">
  <div class="large-12 columns">
    <div class="panel">
 # content
    </div>
  </div>
</div>
<!-- end content -->
{% endblock %}

{% block footer scoped %}
    {% include "pyoes/footer.jinja2" %}
{% endblock %}
